.. _diagrams:

``dhcpcanon`` diagrams
=========================

Finite State Machine diagram
--------------------------------

.. image:: ./images/dhcpcapfsm.*

Classes diagram
---------------

.. image:: ./images/classes_dhcpcanon.*

Packages diagram
--------------------

.. image:: ./images/packages_dhcpcanon.*

Calls diagram
---------------

.. image:: ./images/calls_dhcpcanon.*

Organigram
-----------

This organigram does not reflect the current status of ``dhcpcanon``,
but as it should be changed

.. image:: ./images/organigram_dhcpcanon.*
